@@ -124,9 +124,6 @@ public:
   /// @param[in] envp
   ///     The environment array.
   ///
-  /// @param[in] launch_flags
-  ///     Flags to modify the launch (@see lldb::LaunchFlags)
-  ///
   /// @param[in] stdin_path
   ///     The path to use when re-directing the STDIN of the new
   ///     process. If all stdXX_path arguments are nullptr, a pseudo
@@ -221,14 +218,6 @@ public:
   lldb::SBProcess AttachToProcessWithID(SBListener &listener, lldb::pid_t pid,
                                         lldb::SBError &error);
 
-#if defined(__APPLE__)
-  // We need to keep this around for a build or two since Xcode links
-  // to the 32 bit version of this function. We will take it out soon.
-  lldb::SBProcess AttachToProcessWithID(SBListener &listener,
-                                        ::pid_t pid, // 32 bit int process ID
-                                        lldb::SBError &error); // DEPRECATED
-#endif
-
   //------------------------------------------------------------------
   /// Attach to process with name.
   ///
@@ -480,6 +469,7 @@ public:
   /// Resolve a current file address into a section offset address.
   ///
   /// @param[in] file_addr
+  ///     The file address to resolve.
   ///
   /// @return
   ///     An SBAddress which will be valid if...
@@ -546,7 +536,7 @@ public:
   ///     into this call
   ///
   /// @param[out] error
-  ///     Error information is written here if the memory read fails.
+  ///     Status information is written here if the memory read fails.
   ///
   /// @return
   ///     The amount of data read in host bytes.
@@ -653,7 +643,7 @@ public:
   /// @param[in] source_file
   ///    The file from which to read the breakpoints.
   ///
-  /// @param[out] bkpt_list
+  /// @param[out] new_bps
   ///    A list of the newly created breakpoints.
   ///
   /// @return
@@ -673,7 +663,7 @@ public:
   ///    Only read in breakpoints whose names match one of the names in this
   ///    list.
   ///
-  /// @param[out] bkpt_list
+  /// @param[out] new_bps
   ///    A list of the newly created breakpoints.
   ///
   /// @return
@@ -726,6 +716,10 @@ public:
   // Finds all breakpoints by name, returning the list in bkpt_list.  Returns
   // false if the name is not a valid breakpoint name, true otherwise.
   bool FindBreakpointsByName(const char *name, SBBreakpointList &bkpt_list);
+  
+  void GetBreakpointNames(SBStringList &names);
+  
+  void DeleteBreakpointName(const char *name);
 
   bool EnableAllBreakpoints();
 
@@ -820,6 +814,7 @@ protected:
   friend class SBAddress;
   friend class SBBlock;
   friend class SBBreakpointList;
+  friend class SBBreakpointNameImpl;
   friend class SBDebugger;
   friend class SBExecutionContext;
   friend class SBFunction;
