@@ -12,14 +12,12 @@
 
 #if defined(_WIN32)
 #include "lldb/Host/windows/HostProcessWindows.h"
-namespace lldb_private
-{
+namespace lldb_private {
 typedef HostProcessWindows HostNativeProcess;
 }
 #else
 #include "lldb/Host/posix/HostProcessPosix.h"
-namespace lldb_private
-{
+namespace lldb_private {
 typedef HostProcessPosix HostNativeProcess;
 }
 #endif
