@@ -35,12 +35,14 @@ public:
 
   ~PipePosix() override;
 
-  Error CreateNew(bool child_process_inherit) override;
-  Error CreateNew(llvm::StringRef name, bool child_process_inherit) override;
-  Error CreateWithUniqueName(llvm::StringRef prefix, bool child_process_inherit,
-                             llvm::SmallVectorImpl<char> &name) override;
-  Error OpenAsReader(llvm::StringRef name, bool child_process_inherit) override;
-  Error
+  Status CreateNew(bool child_process_inherit) override;
+  Status CreateNew(llvm::StringRef name, bool child_process_inherit) override;
+  Status CreateWithUniqueName(llvm::StringRef prefix,
+                              bool child_process_inherit,
+                              llvm::SmallVectorImpl<char> &name) override;
+  Status OpenAsReader(llvm::StringRef name,
+                      bool child_process_inherit) override;
+  Status
   OpenAsWriterWithTimeout(llvm::StringRef name, bool child_process_inherit,
                           const std::chrono::microseconds &timeout) override;
 
@@ -57,12 +59,12 @@ public:
   // Close both descriptors
   void Close() override;
 
-  Error Delete(llvm::StringRef name) override;
+  Status Delete(llvm::StringRef name) override;
 
-  Error Write(const void *buf, size_t size, size_t &bytes_written) override;
-  Error ReadWithTimeout(void *buf, size_t size,
-                        const std::chrono::microseconds &timeout,
-                        size_t &bytes_read) override;
+  Status Write(const void *buf, size_t size, size_t &bytes_written) override;
+  Status ReadWithTimeout(void *buf, size_t size,
+                         const std::chrono::microseconds &timeout,
+                         size_t &bytes_read) override;
 
 private:
   int m_fds[2];
