@@ -30,14 +30,6 @@ class UnixSignals;
 // SP/WP decls.
 // ---------------------------------------------------------------
 typedef std::shared_ptr<NativeBreakpoint> NativeBreakpointSP;
-typedef std::shared_ptr<lldb_private::NativeProcessProtocol>
-    NativeProcessProtocolSP;
-typedef std::weak_ptr<lldb_private::NativeProcessProtocol>
-    NativeProcessProtocolWP;
-typedef std::shared_ptr<lldb_private::NativeRegisterContext>
-    NativeRegisterContextSP;
-typedef std::shared_ptr<lldb_private::NativeThreadProtocol>
-    NativeThreadProtocolSP;
 }
 
 #endif // #if defined(__cplusplus)
