@@ -6,6 +6,7 @@ from __future__ import print_function
 import os
 import re
 import subprocess
+import sys
 
 import lldb
 from lldbsuite.test.decorators import *
@@ -18,6 +19,7 @@ class TestMultipleSimultaneousDebuggers(TestBase):
     mydir = TestBase.compute_mydir(__file__)
 
     @skipIfNoSBHeaders
+    @expectedFailureAll(bugnumber="rdar://30564102")
     @expectedFailureAll(
         archs="i[3-6]86",
         bugnumber="multi-process-driver.cpp creates an x64 target")
