@@ -76,17 +76,18 @@ class RegistersIteratorTestCase(TestBase):
 
                     REGs = lldbutil.get_ESRs(frame)
                     if self.platformIsDarwin():
-                        num = len(REGs)
-                        if self.TraceOn():
-                            print(
-                                "\nNumber of exception state registers: %d" %
-                                num)
-                        for reg in REGs:
-                            self.assertTrue(reg)
+                        if self.getArchitecture() != 'armv7' and self.getArchitecture() != 'armv7k':
+                            num = len(REGs)
                             if self.TraceOn():
                                 print(
-                                    "%s => %s" %
-                                    (reg.GetName(), reg.GetValue()))
+                                    "\nNumber of exception state registers: %d" %
+                                    num)
+                            for reg in REGs:
+                                self.assertTrue(reg)
+                                if self.TraceOn():
+                                    print(
+                                        "%s => %s" %
+                                        (reg.GetName(), reg.GetValue()))
                     else:
                         self.assertIsNone(REGs)
 
@@ -99,7 +100,8 @@ class RegistersIteratorTestCase(TestBase):
                     REGs = lldbutil.get_registers(
                         frame, "Exception State Registers")
                     if self.platformIsDarwin():
-                        self.assertIsNotNone(REGs)
+                        if self.getArchitecture() != 'armv7' and self.getArchitecture() != 'armv7k':
+                            self.assertIsNotNone(REGs)
                     else:
                         self.assertIsNone(REGs)
 
