@@ -14,9 +14,6 @@ class MiTestCaseBase(Base):
     myexe = "a.out"
     mylog = "child.log"
 
-    def getCategories(self):
-        return ['lldb-mi']
-
     @classmethod
     def classCleanup(cls):
         TestBase.RemoveTempFile(cls.myexe)
