@@ -22,18 +22,14 @@ namespace lldb_private {
 // CommandObjectGUI
 //-------------------------------------------------------------------------
 
-class CommandObjectGUI : public CommandObjectParsed
-{
+class CommandObjectGUI : public CommandObjectParsed {
 public:
+  CommandObjectGUI(CommandInterpreter &interpreter);
 
-    CommandObjectGUI (CommandInterpreter &interpreter);
-
-    ~CommandObjectGUI() override;
+  ~CommandObjectGUI() override;
 
 protected:
-    bool
-    DoExecute(Args& args,
-	      CommandReturnObject &result) override;
+  bool DoExecute(Args &args, CommandReturnObject &result) override;
 };
 
 } // namespace lldb_private
