@@ -260,7 +260,6 @@ void IRExecutionUnit::GetRunnableInfo(Status &error, lldb::addr_t &func_addr,
 
   llvm::Triple triple(m_module->getTargetTriple());
   llvm::Reloc::Model relocModel;
-  llvm::CodeModel::Model codeModel;
 
   if (triple.isOSBinFormatELF()) {
     relocModel = llvm::Reloc::Static;
@@ -268,9 +267,6 @@ void IRExecutionUnit::GetRunnableInfo(Status &error, lldb::addr_t &func_addr,
     relocModel = llvm::Reloc::PIC_;
   }
 
-  // This will be small for 32-bit and large for 64-bit.
-  codeModel = llvm::CodeModel::JITDefault;
-
   m_module_ap->getContext().setInlineAsmDiagnosticHandler(ReportInlineAsmError,
                                                           &error);
 
@@ -281,7 +277,6 @@ void IRExecutionUnit::GetRunnableInfo(Status &error, lldb::addr_t &func_addr,
       .setRelocationModel(relocModel)
       .setMCJITMemoryManager(
           std::unique_ptr<MemoryManager>(new MemoryManager(*this)))
-      .setCodeModel(codeModel)
       .setOptLevel(llvm::CodeGenOpt::Less);
 
   llvm::StringRef mArch;
@@ -1114,6 +1109,7 @@ bool IRExecutionUnit::CommitOneAllocation(lldb::ProcessSP &process_sp,
   case lldb::eSectionTypeDWARFDebugAbbrev:
   case lldb::eSectionTypeDWARFDebugAddr:
   case lldb::eSectionTypeDWARFDebugAranges:
+  case lldb::eSectionTypeDWARFDebugCuIndex:
   case lldb::eSectionTypeDWARFDebugFrame:
   case lldb::eSectionTypeDWARFDebugInfo:
   case lldb::eSectionTypeDWARFDebugLine:
