@@ -20,7 +20,7 @@
 #define __XPC_PRIVATE_H__
 #include <xpc/xpc.h>
 
-#define LaunchUsingXPCRightName "com.apple.dt.Xcode.RootDebuggingXPCService"
+#define LaunchUsingXPCRightName "com.apple.lldb.RootDebuggingXPCService"
 
 // These XPC messaging keys are used for communication between Host.mm and the
 // XPC service.
@@ -54,7 +54,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "lldb/Core/ArchSpec.h"
 #include "lldb/Core/Communication.h"
 #include "lldb/Core/Module.h"
 #include "lldb/Core/ModuleSpec.h"
@@ -63,6 +62,7 @@
 #include "lldb/Host/ThreadLauncher.h"
 #include "lldb/Target/Platform.h"
 #include "lldb/Target/Process.h"
+#include "lldb/Utility/ArchSpec.h"
 #include "lldb/Utility/CleanUp.h"
 #include "lldb/Utility/DataBufferHeap.h"
 #include "lldb/Utility/DataExtractor.h"
