@@ -13,10 +13,10 @@
 // C++ Includes
 // Other libraries and framework includes
 // Project includes
-#include "lldb/Core/Stream.h"
-#include "lldb/Host/FileSpec.h"
 #include "lldb/Host/StringConvert.h"
 #include "lldb/Interpreter/Args.h"
+#include "lldb/Utility/FileSpec.h"
+#include "lldb/Utility/Stream.h"
 
 using namespace lldb;
 using namespace lldb_private;
@@ -40,9 +40,9 @@ void OptionValuePathMappings::DumpValue(const ExecutionContext *exe_ctx,
   }
 }
 
-Error OptionValuePathMappings::SetValueFromString(llvm::StringRef value,
-                                                  VarSetOperationType op) {
-  Error error;
+Status OptionValuePathMappings::SetValueFromString(llvm::StringRef value,
+                                                   VarSetOperationType op) {
+  Status error;
   Args args(value.str());
   const size_t argc = args.GetArgumentCount();
 
