@@ -11,12 +11,12 @@
 #define liblldb_DWARFDataExtractor_h_
 
 // Other libraries and framework includes.
-#include "lldb/Core/DataExtractor.h"
 #include "lldb/Core/dwarf.h"
+#include "lldb/Utility/DataExtractor.h"
 
 namespace lldb_private {
 
-class DWARFDataExtractor : public lldb_private::DataExtractor {
+class DWARFDataExtractor : public DataExtractor {
 public:
   DWARFDataExtractor() : DataExtractor(), m_is_dwarf64(false) {}
 
