@@ -8,19 +8,12 @@
 //
 //===----------------------------------------------------------------------===//
 
-#if defined(_MSC_VER) && (_HAS_EXCEPTIONS == 0)
-// Workaround for MSVC standard library bug, which fails to include <thread>
-// when
-// exceptions are disabled.
-#include <eh.h>
-#endif
-
 #include <sstream>
 
 #include "gtest/gtest.h"
 
 #include "Plugins/ExpressionParser/Go/GoParser.h"
-#include "lldb/Core/Error.h"
+#include "lldb/Utility/Status.h"
 
 using namespace lldb_private;
 
@@ -71,7 +64,7 @@ testing::AssertionResult CheckStatement(const char *_s, const char *c_expr,
   GoParser parser(code);
   std::unique_ptr<GoASTStmt> stmt(parser.Statement());
   if (parser.Failed() || !stmt) {
-    Error err;
+    Status err;
     parser.GetError(err);
     return testing::AssertionFailure() << "Error parsing " << c_expr << "\n\t"
                                        << err.AsCString();
